#
# spec file for package collectl
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           collectl
Version:        4.0.2
Release:        6.1
Summary:        Collects data that describes the current system status
License:        Artistic-1.0 and GPL-2.0+
Group:          System/Monitoring
Url:            http://collectl.sourceforge.net
Source0:        http://sourceforge.net/projects/collectl/files/collectl/%{name}-%{version}/%{name}-%{version}.src.tar.gz
Source1:        collectl.service
Source2:        collectl.sysconfig
BuildRequires:  pkgconfig(systemd)
BuildArch:      noarch
%{?systemd_requires}

%description
Unlike most monitoring tools that either focus on a small set of
statistics, format their output in only one way, run either
interatively or as a daemon but not both, collectl tries to do it all.

%prep
%setup -q

%build

%install
# Install collectl in /usr/bin and link it in /usr/sbin
install -m 755 -D collectl %{buildroot}%{_bindir}/collectl
mkdir -p %{buildroot}/%{_sbindir}
ln -s  %{_bindir}/collectl %{buildroot}/%{_sbindir}/collectl
install -m 644 -D collectl.conf %{buildroot}/%{_sysconfdir}/collectl.conf
install -D formatit.ph %{buildroot}%{_datadir}/%{name}/formatit.ph
install -D lexpr.ph %{buildroot}%{_datadir}/%{name}/lexpr.ph
install -D gexpr.ph %{buildroot}%{_datadir}/%{name}/gexpr.ph
install -D misc.ph %{buildroot}%{_datadir}/%{name}/misc.ph
install -D hello.ph %{buildroot}%{_datadir}/%{name}/hello.ph
install -D graphite.ph %{buildroot}%{_datadir}/%{name}/graphite.ph
install -D vmstat.ph %{buildroot}%{_datadir}/%{name}/vmstat.ph
install -m 755 -D %{SOURCE1} %{buildroot}/%{_unitdir}/collectl.service
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rccollectl
install -m 644 -D %{SOURCE2} %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.collectl
install -m 644 -D man1/collectl.1 %{buildroot}%{_mandir}/man1/collectl.1

%post
%fillup_only
%service_add_post %{name}.service

%pre
%fillup_only
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr(-,root,root)
%doc docs/* COPYING ARTISTIC GPL README RELEASE-collectl
%{_unitdir}/collectl.service
%{_localstatedir}/adm/fillup-templates/sysconfig.collectl
%config(noreplace) %{_sysconfdir}/collectl.conf
%{_bindir}/collectl
%{_sbindir}/collectl
%{_sbindir}/rccollectl
%{_datadir}/collectl
%{_mandir}/man1/collectl.1.gz

%changelog
* Thu May 28 2015 tabraham@suse.com
- Update to 4.0.2
  * add /bin/bash to list of 'known shells' excluded from output with
  - -procopt k
  * generalize ethernet network device name to include ALL names
    matching type 'p\dp' so we pick up p2p, p3p, p4p... [thanks Matt]
  * collect nr_shmem so we can track shared memory, apparently something
    I thought of but never acted on [thanks Christian]
  * do not include guest cpu metrics in totals since already accounted
    for in user time
* Mon Apr 20 2015 mpluskal@suse.com
- Update to 4.0.0
  * for a complete list of changes see RELEASE-collectl
- Cleanup spec-file with spec-cleaner
- Use url for source
- Fix broken rcservice symlink
- Add ommited systemd service pre macro
* Wed Sep 24 2014 tabraham@suse.com
- Update to version 3.7.4
  See RELEASE-collectl for changes
* Thu Dec 12 2013 p.drouand@gmail.com
- Update to version 3.6.9
  + Typo in network plot header loop resulted in infinite loop
  + remove $int/secs from numa hit rate calc AND add more precision
    to its output
- Changes from 3.6.8
  + new flag $exportComm must be set in gexpr/ganglia so that they won't
    generate an error if run without -f or -A
  + new switch: --intfilt allows filtering of interrupts
  + always log messages of type F/E to syslog in daemon mode even if
  - m is not set
  + wasn't dealing correctly with missing whitespace after network name in
    /proc/dev/net in initRecord()
  + updated init.d script for suse per the maintainer's instructions
  + extra spaces were being printed in plot mode for tpc stats
  + added entry to envrules.std to deal with intel Phi Co-Processor
  + debian init.d script now does 'exit 1' if status reports 'not running'
  + rawnetignore switch wasn't working correctly
  + found/fixed some subtle problems with --procanalyze as well as some cleanup
  - need to ignore first sample after initializing summary arrays
  - need to init summary hashes for thrutime and accumT because get uninit var
    in print routine is only a single process entry
  - found a typo in procAnalyze() to a $usecs which wasn't being used!
  - added error check to make sure --procanalyze with -P requires -s
  + added a little more debugging output for -d128
  + discovered dynamic disk/network detail names for interactive mode were not
    being reported correctly.  sounds a lot worse than it is because this is
    typically not done very often nor are disks/networks very dynamic except in
    large, virtualized environments such as clouds
  + add to list of devices to exlude from network summary data: tap, dp and nl,
    which are associated with openstack cinder.  remember you can always add
    more to that list with --netfilt
  + $lastHour was never referenced and dayInit() called every time a log was
    created so fix logic to update $lastHour correctly AND call initDay() one
    time and do it before newLog() called.
  + closed a couple of file handles that were left open and reportedly
    causing some defunct processes with -sx.
  + fixed bug in lustre stats recording
  + clarified --showsubopts text about disk and network filters in that they
    apply to both summary and detail data output
  + fixed problem with --import and --stats
  + --statsopt a didn't work because when changed some internal logic missed
    changing a test of $timestampFlag to $timestampCounter[$rawPFlag] and so
    now $timestampCount can be removed entirely
  + clear $firstpass after 1st pass during playback
  + make sure filename initialized before calling loadConfig so if there is
    an error logsys() doesn't get an undefined var warning
  + to be safe, remove any quotes on net/dsk filters in case included by
    mistake in DaemonCommands string
  + tightened up tests to see if daemonized collectl already running
  + if no hiRes::Time, fudge the value of $microInterval based on -i
  + new --procOpt k, removes known shells from process listing with -sZ,
    currently set to /bin.sh, /usr/bin/perl, /usr/bin/python and python
  + fixed varname in lexpr: $debug should have been $lexDebug
- Remove init-cleanup.patch; merged on upstream release
* Sat Oct 26 2013 p.drouand@gmail.com
- Drop sysvinit support; none of target distributions use sysvinit
  anymore
- Add systemd support
- Install collectl in /usr/bin to get it launchable with systemd and
  link it in /usr/sbin
- Add a sysconfig file
* Thu Jun  6 2013 tabraham@suse.com
- deleted bug-793027.patch : deprecated
- init-cleanup.patch : init script cleanup
- see RELEASE-collectl for list of changes between 3.4.3 and 3.6.7
* Tue Mar  5 2013 coolo@suse.com
- update license to new format
* Wed Dec  5 2012 tabraham@suse.com
- bug-793027.patch: fix for collectl init script (bnc #793027)
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Nov  5 2010 hvogel@novell.com
- Update to version 3.4.3
  * when errors detected during initialization not skipping subsequent checks
  * added --dskfilt
  * added check for client-side OST uuid status 'DEACTIVATED'
  * support for CPUs dynamically changing stats and going off/on-line
  * new feature: select process by UID range
  * do not issue 'stty' if !PC, running on terminal and !background.
  * added --netfilt
  * changed disk details to use 'cvt()' for reporting number of I/Os since DM
    numbers
  * 2 new process sort fields: pid and cpu
  * only look at $cpuDisabledFlag when processing CPU data
* Tue Apr  6 2010 hvogel@novell.com
- Update to version 3.4.1
  * new switch --umask for setting mode to files collectl creates
  * support for Fusion-IO disks
  * Support for OFED 1.5
  * Improved performance of playback
  * Added LSB headers to all start scripts
  * New data collection/reporting API
  * New export: gexpr, for exporting data to ganglia
  * Added NFS V4 support and collection
  * Expanded contents of verbose memory output
  * Added Power to environmental monitoring
  * Allow multiple clients to connect when is server mode
  * Added fields to --top for monitoring slabs
  * Expanded --top functionality.
  * Enhanced MDS stats to support lustre 1.6.5
  * Added --grep switch to allow searching/reporting data in raw files
  * A couple of switch names changed to be more consistent
  * Improved help
* Thu Jul  3 2008 hvogel@suse.de
- Initial package, Version 2.6.4
